/// <reference types="npmcli__package-json" />
import type { SyncCompilers, AsyncCompilers } from './types/compilers.js';
import type { RawConfiguration, Configuration, WorkspaceConfiguration } from './types/config.js';
import type { PackageJson } from '@npmcli/package-json';
type ConfigurationManagerOptions = {
    cwd: string;
    isProduction: boolean;
};
export type Workspace = {
    name: string;
    pkgName?: string;
    dir: string;
    ancestors: string[];
    config: WorkspaceConfiguration;
};
export declare class ConfigurationChief {
    cwd: string;
    isProduction: boolean;
    config: Configuration;
    manifestPath?: string;
    manifest?: PackageJson;
    ignoreWorkspaces: string[];
    manifestWorkspaces: Map<string, string>;
    additionalWorkspaces: Set<string>;
    workspaceDirs: string[];
    workspaces: Workspace[];
    localWorkspaces: Set<string>;
    resolvedConfigFilePath?: string;
    constructor({ cwd, isProduction }: ConfigurationManagerOptions);
    init(): Promise<void>;
    getCompilers(): [SyncCompilers, AsyncCompilers];
    getRules(): import("./types/issues.js").Rules;
    normalize(rawLocalConfig: RawConfiguration): {
        rules: {
            files: import("./types/issues.js").IssueSeverity;
            dependencies: import("./types/issues.js").IssueSeverity;
            devDependencies: import("./types/issues.js").IssueSeverity;
            unlisted: import("./types/issues.js").IssueSeverity;
            binaries: import("./types/issues.js").IssueSeverity;
            unresolved: import("./types/issues.js").IssueSeverity;
            exports: import("./types/issues.js").IssueSeverity;
            types: import("./types/issues.js").IssueSeverity;
            nsExports: import("./types/issues.js").IssueSeverity;
            nsTypes: import("./types/issues.js").IssueSeverity;
            duplicates: import("./types/issues.js").IssueSeverity;
            enumMembers: import("./types/issues.js").IssueSeverity;
            classMembers: import("./types/issues.js").IssueSeverity;
        };
        include: string[];
        exclude: string[];
        ignore: string[];
        ignoreBinaries: string[];
        ignoreDependencies: string[];
        ignoreExportsUsedInFile: boolean | Partial<Record<"function" | "type" | "enum" | "class" | "interface" | "member", boolean>>;
        ignoreWorkspaces: string[];
        syncCompilers: Map<string, (args_0: string, ...args_1: unknown[]) => string>;
        asyncCompilers: Map<string, (args_0: string, ...args_1: unknown[]) => Promise<string>>;
        workspaces: Record<string, WorkspaceConfiguration>;
    };
    setWorkspaces(): Promise<void>;
    private getManifestWorkspaces;
    private getAdditionalWorkspaces;
    private getAllWorkspaceNames;
    private getAllWorkspaces;
    getEnabledWorkspaces(): Workspace[];
    getDescendentWorkspaces(name: string): string[];
    getIgnoredWorkspaces(): string[];
    getIgnoredWorkspacesFor(name: string): string[];
    getNegatedWorkspacePatterns(name: string): string[];
    private getConfigKeyForWorkspace;
    getConfigForWorkspace(workspaceName: string): WorkspaceConfiguration;
    getIssueTypesToReport(): import("./types/issues.js").Report;
    findWorkspaceByFilePath(filePath: string): Workspace | undefined;
    findWorkspaceByPackageName(packageName: string): Workspace | undefined;
    getUnusedIgnoredWorkspaces(): string[];
}
export {};
