import { compact } from '../../util/array.js';
import { isInternal } from '../../util/path.js';
import { timerify } from '../../util/Performance.js';
import { hasDependency, load } from '../../util/plugin.js';
export const NAME = 'TypeScript';
export const ENABLERS = ['typescript'];
export const isEnabled = ({ dependencies }) => hasDependency(dependencies, ENABLERS);
export const CONFIG_FILE_PATTERNS = ['tsconfig.json'];
const findTypeScriptDependencies = async (configFilePath) => {
    const config = await load(configFilePath);
    if (!config)
        return [];
    const extend = config.extends ? [config.extends].flat().filter(extend => !isInternal(extend)) : [];
    const plugins = compact(config.compilerOptions?.plugins?.map(plugin => plugin.name) ?? []);
    const importHelpers = config.compilerOptions?.importHelpers ? ['tslib'] : [];
    return [...extend, ...plugins, ...importHelpers];
};
export const findDependencies = timerify(findTypeScriptDependencies);
